GUI
===

Papis is a program mainly intended for the command line, however,
some experimental frontends have been conceived for it and are
already downloadable from pip.

See for instance

- `papis-rofi <https://papis-rofi.readthedocs.io/en/latest>`__
- `papis-dmenu <https://papis-dmenu.readthedocs.io/en/latest>`__


And more to come!
